pub struct DebugState {
pub DebugConfigurationProviders: Arc<Mutex<HashMap<String, DebugConfigurationProviderRegistration>>>,
pub DebugAdapterDescriptorFactories: Arc<Mutex<HashMap<String, DebugAdapterDescriptorFactoryRegistration>>>,
}Expand description
Debug state containing debug provider registrations.
Fields
DebugConfigurationProviders: Arc<Mutex<HashMap<String, DebugConfigurationProviderRegistration>>>Debug configuration providers organized by debug type.
DebugAdapterDescriptorFactories: Arc<Mutex<HashMap<String, DebugAdapterDescriptorFactoryRegistration>>>Debug adapter descriptor factories organized by debug type.
Implementations
Sourceimpl DebugState
impl DebugState
Sourcepub fn RegisterDebugConfigurationProvider(
&self,
debug_type: String,
provider_handle: u32,
sidecar_identifier: String,
) -> Result<(), String>
pub fn RegisterDebugConfigurationProvider( &self, debug_type: String, provider_handle: u32, sidecar_identifier: String, ) -> Result<(), String>
Registers a debug configuration provider.
Sourcepub fn GetDebugConfigurationProvider(
&self,
debug_type: &str,
) -> Option<DebugConfigurationProviderRegistration>
pub fn GetDebugConfigurationProvider( &self, debug_type: &str, ) -> Option<DebugConfigurationProviderRegistration>
Gets a debug configuration provider registration by debug type.
Sourcepub fn RegisterDebugAdapterDescriptorFactory(
&self,
debug_type: String,
factory_handle: u32,
sidecar_identifier: String,
) -> Result<(), String>
pub fn RegisterDebugAdapterDescriptorFactory( &self, debug_type: String, factory_handle: u32, sidecar_identifier: String, ) -> Result<(), String>
Registers a debug adapter descriptor factory.
Sourcepub fn GetDebugAdapterDescriptorFactory(
&self,
debug_type: &str,
) -> Option<DebugAdapterDescriptorFactoryRegistration>
pub fn GetDebugAdapterDescriptorFactory( &self, debug_type: &str, ) -> Option<DebugAdapterDescriptorFactoryRegistration>
Gets a debug adapter descriptor factory registration by debug type.
Sourcepub fn GetAllDebugConfigurationProviders(
&self,
) -> HashMap<String, DebugConfigurationProviderRegistration>
pub fn GetAllDebugConfigurationProviders( &self, ) -> HashMap<String, DebugConfigurationProviderRegistration>
Gets all registered debug configuration providers.
Sourcepub fn GetAllDebugAdapterDescriptorFactories(
&self,
) -> HashMap<String, DebugAdapterDescriptorFactoryRegistration>
pub fn GetAllDebugAdapterDescriptorFactories( &self, ) -> HashMap<String, DebugAdapterDescriptorFactoryRegistration>
Gets all registered debug adapter descriptor factories.